satsim.time package — SatSim 0.12.0 documentation

# satsim.time package

class `satsim.time.` `TimeWrapper`(other)

  Bases: `skyfield.timelib.Time`

  This class implements the __hash__ function for the Skyfield Time.

`satsim.time.` `to_utc_list`(t)

  Convert a Skyfield Time object to UTC in array form.

  Parameters

    t – Time, time to convert to UTC

  Returns

    A list with UTC values for year, month, day, hour, minutes, seconds

`satsim.time.` `utc`(year, month, day, hour, minute, seconds)

  Generate a Skyfield Time object based on UTC time.

  Parameters

    - year – int, UTC year

    - month – int, UTC month of year

    - day – int, UTC day of month

    - hour – int, UTC hour

    - minute – int, UTC minute

    - seconds – float, UTC seconds

  Returns

    A Skyfield Time object

`satsim.time.` `utc_from_list`(t_list, delta_sec=0)

  Generate a Skyfield Time object based on UTC time in array form.

  Parameters

    - t_list – list, UTC as [year, month, day, hour, minute, seconds]

    - delta_sec – float, seconds to add

  Returns

    A Skyfield Time object

`satsim.time.` `utc_from_list_or_scalar`(t, delta_sec=0, default_t=None)

  Generate a Skyfield Time object based on a UTC time in array or scalar form. Scalar form requires default_t to be defined.

  Parameters

    - t – list or float, UTC as [year, month, day, hour, minute, seconds] or delta seconds from default_t

    - delta_sec – float, seconds to add

    - default_t – list, UTC as [year, month, day, hour, minute, seconds], required if t is None or a scalar

  Returns

    A Skyfield Time object